summaryrefslogtreecommitdiffstats
path: root/test/titerate.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2007-03-08 20:10:12 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2007-03-08 20:10:12 (GMT)
commit74a30fff3e0fcd8919ced487abd03eefd27d57c1 (patch)
tree2df0a0d2cfc51cce067f25e503e6dfd26c8e827d /test/titerate.c
parent25bb6f5dd8af42d2facaab26f0cdeb7fc76456ae (diff)
downloadhdf5-74a30fff3e0fcd8919ced487abd03eefd27d57c1.zip
hdf5-74a30fff3e0fcd8919ced487abd03eefd27d57c1.tar.gz
hdf5-74a30fff3e0fcd8919ced487abd03eefd27d57c1.tar.bz2
[svn-r13477] Description:
The main purpose of this checkin was to eliminate the space used for tracking creation time indices when there is no way they can be used (i.e. attributes can't be shared in the file and the user hasn't turned on attribute creation tracking), however there were some other minor changes which crept in: - Fix a cache locking deadlock when a shared attribute and one of its components end up in the same fractal heap direct block. (This is fixed the "slow" way for right now, until John has time to add support for readers/writer locking to the cache. - Optimize attribute copying when a copy will be kept during a v2 B-tree search. - When freeing a block on disk, attempt to merge it with the metadata and "small data" aggregators. Tested on: Mac OS X/32 10.4.8 (amazon) FreeBSD/32 6.2 (duty)
Diffstat (limited to 'test/titerate.c')
-rw-r--r--test/titerate.c18
1 files changed, 12 insertions, 6 deletions
diff --git a/test/titerate.c b/test/titerate.c
index 10ddf17..e60d98a 100644
--- a/test/titerate.c
+++ b/test/titerate.c
@@ -473,9 +473,12 @@ static void test_iter_attr(hid_t fapl, hbool_t new_format)
/* Verify that the index is the correct value */
VERIFY(idx, (unsigned)i, "H5Aiterate");
- /* Verify that the correct name is retrieved */
- if(HDstrcmp(info.name, anames[idx - 1]) != 0)
- TestErrPrintf("%u: Attribute iteration function didn't return 'two' correctly!\n", __LINE__);
+ /* Don't check name when new format is used */
+ if(!new_format) {
+ /* Verify that the correct name is retrieved */
+ if(HDstrcmp(info.name, anames[idx - 1]) != 0)
+ TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = '%s', anames[idx - 1] = '%s'!\n", __LINE__, info.name, anames[idx - 1]);
+ } /* end if */
} /* end while */
VERIFY(ret, -1, "H5Aiterate");
if(i != 50 || idx != 50)
@@ -496,9 +499,12 @@ static void test_iter_attr(hid_t fapl, hbool_t new_format)
/* Verify that the index is the correct value */
VERIFY(idx, (unsigned)i + 10, "H5Aiterate");
- /* Verify that the correct name is retrieved */
- if(HDstrcmp(info.name, anames[idx - 1]) != 0)
- TestErrPrintf("Attribute iteration function didn't return changing correctly!\n");
+ /* Don't check name when new format is used */
+ if(!new_format) {
+ /* Verify that the correct name is retrieved */
+ if(HDstrcmp(info.name, anames[idx - 1]) != 0)
+ TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = '%s', anames[idx - 1] = '%s'!\n", __LINE__, info.name, anames[idx - 1]);
+ } /* end if */
} /* end while */
VERIFY(ret, -1, "H5Aiterate");
if(i != 40 || idx != 50)